.. _plotting_ref:

:mod:`nilearn.plotting`: Plotting Brain Data
============================================

Plotting
--------

.. automodule:: nilearn.plotting
   :no-members:
   :no-inherited-members:

.. No relevant user manual section yet.

Functions
^^^^^^^^^

.. currentmodule:: nilearn.plotting

.. autosummary::
   :toctree: generated/
   :template: function.rst

   find_cut_slices
   find_xyz_cut_coords
   find_parcellation_cut_coords
   find_probabilistic_atlas_cut_coords
   plot_anat
   plot_carpet
   plot_connectome
   plot_contrast_matrix
   plot_design_matrix
   plot_design_matrix_correlation
   plot_epi
   plot_event
   plot_glass_brain
   plot_img
   plot_img_on_surf
   plot_markers
   plot_matrix
   plot_prob_atlas
   plot_roi
   plot_stat_map
   plot_surf
   plot_surf_contours
   plot_surf_roi
   plot_surf_stat_map
   show
   view_surf
   view_img_on_surf
   view_connectome
   view_markers
   view_img

Comparing images
----------------

.. automodule:: nilearn.plotting.img_comparison
   :no-members:
   :no-inherited-members:

.. No relevant user manual section yet.

Functions
^^^^^^^^^

.. currentmodule:: nilearn.plotting.img_comparison

.. autosummary::
   :toctree: generated/
   :template: function.rst

   plot_bland_altman
   plot_img_comparison


Interacting with figures
------------------------

.. automodule:: nilearn.plotting.displays
   :no-members:
   :no-inherited-members:

.. No relevant user manual section yet.

Classes
^^^^^^^

.. currentmodule:: nilearn.plotting.displays

.. autosummary::
   :toctree: generated/
   :template: class.rst

   PlotlySurfaceFigure

Axes
""""

.. currentmodule:: nilearn.plotting.displays

.. autosummary::
   :toctree: generated/
   :template: class.rst

   BaseAxes
   CutAxes
   GlassBrainAxes

Projectors
""""""""""

.. currentmodule:: nilearn.plotting.displays

.. autosummary::
   :toctree: generated/
   :template: class.rst

   OrthoProjector
   LZRYProjector
   LYRZProjector
   LYRProjector
   LZRProjector
   LRProjector
   LProjector
   RProjector
   XZProjector
   YZProjector
   YXProjector
   XProjector
   YProjector
   ZProjector

Slicers
"""""""

.. currentmodule:: nilearn.plotting.displays

.. autosummary::
   :toctree: generated/
   :template: class.rst

   BaseSlicer
   OrthoSlicer
   MosaicSlicer
   TiledSlicer
   XSlicer
   XZSlicer
   YXSlicer
   YZSlicer
   YSlicer
   ZSlicer

Functions
^^^^^^^^^

.. currentmodule:: nilearn.plotting.displays

.. autosummary::
   :toctree: generated/
   :template: function.rst

   get_projector
   get_slicer
